@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2012-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -178,10 +178,6 @@ QString CustomLogWidget::toHtml() const
         case EndLine:
             logText = QStringLiteral("<br/>");
             break;
-        default:
-            qCDebug(LIBKDEPIM_LOG) << "LogType undefined" << type;
-            logText += itemWidget->text();
-            break;
         }
         result += QLatin1String("<p>") + logText + QLatin1String("</p>") + QLatin1Char('\n');
     }
