@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -18,10 +18,8 @@
 
 */
 
-#include <kaboutdata.h>
 #include <QApplication>
 #include <QCommandLineParser>
-#include <KLocalizedString>
 #include <QStandardPaths>
 
 #include <addressline/completionconfiguredialog/completionconfiguredialog.h>
@@ -29,15 +27,11 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("testcompletionconfiguredialog"), i18n("Test CompletionConfigureDialog"), QStringLiteral("0.1"));
     QCommandLineParser parser;
     QStandardPaths::setTestModeEnabled(true);
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     KPIM::CompletionConfigureDialog dlg;
     dlg.show();
